import os
import board
import sdioio
import storage
import time
import busio
import displayio
displayio.release_displays()
import terminalio
from adafruit_display_text import label
import adafruit_ssd1327
#import adafruit_displayio_sh1107

def main():
    # initialize bus
    i2c_bus = initialize_i2c_bus( board.SCL, board.SDA )
    if not i2c_bus:
        operational = False

    sdcard = sdioio.SDCard(
        clock=board.SDIO_CLOCK,
        command=board.SDIO_COMMAND,
        data=board.SDIO_DATA,
        frequency=15000000)
    print(sdcard.frequency)

    vfs = storage.VfsFat(sdcard)

    storage.mount(vfs, "/sd")

    # initialize display and show welcome screen
    if i2c_bus:
        displayio.release_displays()
        display_128x128 = initialize_display( i2c_bus )
        if False: #display_128x128:
            splash = show_welcome_screen( display_128x128 )
            display_128x128.show( splash )

    if True:
        time.sleep(0.1)
        with open( "/sd/test.txt", "w" ) as f:
            f.write( "year, month, day, batch\n" )
            f.write( "2022, 12, 30, 0\n" )


        with open("/sd/test.txt", "r") as f:
            print("Printing lines in file:")
            print()
            line = f.readline()
            while line != '':
                print(line)
                line = f.readline()
        print()
    print( "Program Completed" )

def initialize_display( i2c_bus ):
    try:
        display_bus = displayio.I2CDisplay(i2c_bus, device_address=0x3D)
        WIDTH = 128
        HEIGHT = 128
        BORDER = 8
        FONTSCALE = 1
        display = False
        display = adafruit_ssd1327.SSD1327(display_bus, width=WIDTH, height=HEIGHT)
        #display = adafruit_displayio_sh1107.SH1107(display_bus, width=128, height=64)

    except ValueError:
        print( "no display found" )
        display = False
    return display

def initialize_i2c_bus( SCL_pin, SDA_pin ):
    try:
        i2c_bus = busio.I2C( SCL_pin, SDA_pin )
    except ValueError as err:
        print( "i2c bus failed to initialize '{}'".format( err ))
        i2c_bus = False
    return i2c_bus

def show_welcome_screen( display ):
    splash = displayio.Group()
    display.show(splash)

    WIDTH = 128
    HEIGHT = 128
    BORDER = 8
    FONTSCALE = 2

    # Draw a background rectangle, but not the full display size
    color_bitmap = displayio.Bitmap(
        display.width - BORDER * 2, display.height - BORDER * 2, 1
    )
    color_palette = displayio.Palette(1)
    color_palette[0] = 0xFFFFFF  # White
    bg_sprite = displayio.TileGrid(
        color_bitmap, pixel_shader=color_palette, x=BORDER, y=BORDER
    )
    splash.append(bg_sprite)

    # Draw a smaller inner rectangle
    inner_bitmap = displayio.Bitmap(
        display.width - BORDER * 4, display.height - BORDER * 4, 1
    )
    inner_palette = displayio.Palette(1)
    inner_palette[0] = 0x888888  # Gray
    inner_sprite = displayio.TileGrid(
        inner_bitmap, pixel_shader=inner_palette, x=BORDER * 2, y=BORDER * 2
    )
    splash.append(inner_sprite)

    # Draw a label
    text = "STELLA"
    text_area = label.Label(terminalio.FONT, text=text, color=0xFFFFFF)
    text_width = text_area.bounding_box[2] * FONTSCALE
    text_group = displayio.Group(
        scale=FONTSCALE,
        x=display.width // 2 - text_width // 2,
        y=display.height // 2,
    )
    text_group.append(text_area)  # Subgroup for text scaling
    splash.append(text_group)
    return splash

main()
